Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(471)

Unified Diff: remoting/host/posix/signal_handler.h

Issue 10905081: Pass Me2Me config via stdin. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Reinstate and improve error handling. Created 8 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « remoting/host/posix/sighup_listener.cc ('k') | remoting/host/posix/signal_handler.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: remoting/host/posix/signal_handler.h
diff --git a/remoting/host/posix/sighup_listener.h b/remoting/host/posix/signal_handler.h
similarity index 51%
rename from remoting/host/posix/sighup_listener.h
rename to remoting/host/posix/signal_handler.h
index 48140a39f9a4460bcf877dae949822ec64f2a3cb..caf89efb567d69aa312385f516f2504da7cdd641 100644
--- a/remoting/host/posix/sighup_listener.h
+++ b/remoting/host/posix/signal_handler.h
@@ -6,17 +6,20 @@
// and trigger the specified callback. It is used on Linux and Mac in order to
// reload the me2me host configuration.
-#ifndef REMOTING_HOST_POSIX_SIGHUP_LISTENER_H_
-#define REMOTING_HOST_POSIX_SIGHUP_LISTENER_H_
+#ifndef REMOTING_HOST_POSIX_SIGNAL_HANDLER_H_
+#define REMOTING_HOST_POSIX_SIGNAL_HANDLER_H_
#include "base/callback_forward.h"
namespace remoting {
-// Register for SIGHUP notifications on the current thread, which must have
-// an associated MessageLoopForIO.
-bool RegisterHupSignalHandler(const base::Closure& callback);
+typedef base::Callback<void(int)> SignalHandler;
+
+// Register for signal notifications on the current thread, which must have
+// an associated MessageLoopForIO. Multiple calls to RegisterSignalHandler
+// must all be made on the same thread.
+bool RegisterSignalHandler(int signal_number, const SignalHandler& handler);
} // namespace remoting
-#endif // REMOTING_HOST_POSIX_SIGHUP_LISTENER_H_
+#endif // REMOTING_HOST_POSIX_SIGNAL_HANDLER_H_
« no previous file with comments | « remoting/host/posix/sighup_listener.cc ('k') | remoting/host/posix/signal_handler.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698